==> kadu_0.11.0.orig.tar.bz2: kadu-0.11.0/plugins/history/translations/history_en.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="en_US">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>History</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Chats History</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save messages in history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save chats with anonymous users</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Status Changes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save status changes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save status changes in history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save status only with description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Quotation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Quote message in chat window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>General</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>View history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do not quote messages older than</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Kadu</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BuddyStatusDatesModel</name>
    <message>
        <source>Date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Length</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ChatDatesModel</name>
    <message>
        <source>Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Length</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>History</name>
    <message>
        <source>Clear History</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 day(s) %2 hour(s)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HistoryChatsModel</name>
    <message>
        <source>Statuses</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SMSes</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HistoryWindow</name>
    <message>
        <source>History</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Remove entries</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>by date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>From</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>To</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Clear Chat History</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Clear Status History</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Clear SMS History</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Kadu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>There is no history storage plugin loaded!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <source>Chat history</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ShowHistoryActionDescription</name>
    <message>
        <source>View Chat History</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show last %1 messages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show messages since yesterday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show messages from last 7 days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show messages from last 30 days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show whole history</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SmsDatesModel</name>
    <message>
        <source>Date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Length</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> kadu-0.12.2.tar.bz2: kadu-0.12.2/plugins/history/translations/history_en.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="en_US">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>History</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Chats History</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save messages in history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save chats with anonymous users</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Status Changes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save status changes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save status changes in history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save status only with description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Quotation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Quote message in chat window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>General</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>View history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do not quote messages older than</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Kadu</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ChatHistoryTab</name>
    <message>
        <source>&amp;Clear Chat History</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>History</name>
    <message>
        <source>Clear History</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 day(s) %2 hour(s)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HistoryBuddyDataWindowAddons</name>
    <message>
        <source>Store history</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HistoryChatDataWindowAddons</name>
    <message>
        <source>Store history</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HistoryMessagesTab</name>
    <message>
        <source>&amp;Remove entries</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Filter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Kadu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do you really want to delete history?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HistoryQueryResultsModel</name>
    <message>
        <source>Chat</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HistoryWindow</name>
    <message>
        <source>History</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Clear Status History</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Clear SMS History</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Chats</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Statuses</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SMS</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <source>Chat history</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchTab</name>
    <message>
        <source>Search for:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Chats</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> - All chats - </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Statuses</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> - All buddies - </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Smses</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> - All recipients - </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>By date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>to</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Chat</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Buddy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Recipient</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ShowHistoryActionDescription</name>
    <message>
        <source>View Chat History</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show last %1 messages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show messages since yesterday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show messages from last 7 days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show messages from last 30 days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show whole history</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
